SFPE Handbook of Fire Protection Engineering
============================================

Society of Fire Protection Engineers Handbook calculations.

.. automodule:: ofire.sfpe_handbook
   :members:
   :undoc-members:
   :show-inheritance:

Chapter 14
----------

.. automodule:: ofire.sfpe_handbook.chapter_14
   :members:
   :undoc-members:
   :show-inheritance:

Alpert Correlations
~~~~~~~~~~~~~~~~~~~

.. automodule:: ofire.sfpe_handbook.chapter_14.alpert
   :members:
   :undoc-members:
   :show-inheritance:

Heat Release Rate Correlations
""""""""""""""""""""""""""""""

.. automodule:: ofire.sfpe_handbook.chapter_14.alpert.heat_release
   :members:
   :undoc-members:
   :show-inheritance: